@@ -14,10 +14,10 @@ def test_list_bags():
 
 	config = {
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
-		"instance_tiddlers": [
-			("alpha", ["%s/alpha/index.recipe" % REPO_DIR]),
-			("bravo", ["%s/bravo/index.recipe" % REPO_DIR])
-		]
+		"instance_tiddlers": {
+			"alpha": ["%s/alpha/index.recipe" % REPO_DIR],
+			"bravo": ["%s/bravo/index.recipe" % REPO_DIR]
+		}
 	}
 	env = { "tiddlyweb.config": config }
 	store = Storage(env)
@@ -32,10 +32,10 @@ def test_list_bags_in_store():
 
 	config = {
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
-		"instance_tiddlers": [
-			("alpha", ["%s/alpha/index.recipe" % REPO_DIR]),
-			("bravo", ["%s/bravo/index.recipe" % REPO_DIR])
-		]
+		"instance_tiddlers": {
+			"alpha": ["%s/alpha/index.recipe" % REPO_DIR],
+			"bravo": ["%s/bravo/index.recipe" % REPO_DIR]
+		}
 	}
 	env = { "tiddlyweb.config": config }
 	store = Store(config["server_store"][0], env)
