@@ -16,7 +16,7 @@ def test_list_recipes():
 
 	config = {
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
-		"instance_tiddlers": []
+		"instance_tiddlers": {}
 	}
 	env = { "tiddlyweb.config": config }
 	store = Storage(env)
@@ -35,7 +35,7 @@ def test_list_recipes_in_store():
 
 	config = {
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
-		"instance_tiddlers": []
+		"instance_tiddlers": {}
 	}
 	env = { "tiddlyweb.config": config }
 	store = Store(config["server_store"][0], env)
